==> webpdf-wsclient-10.0.1-sources.jar: net/webpdf/wsclient/schema/operation/ConverterOfficeWordType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p165541_="https://jakarta.ee/xml/ns/jaxb" xmlns:p356920_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;&#13;
 *                     Defines the settings to be used when converting Word (docx) documents.&#13;
 *                 &lt;/p&gt;
 * </pre>
 * 
 * <p>Java class for ConverterOfficeWordType complex type</p>.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.</p>
 * 
 * <pre>{@code
 * <complexType name="ConverterOfficeWordType">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <all>
 *         <element name="form" type="{http://schema.webpdf.de/1.0/operation}ConverterOfficeFormType" minOccurs="0"/>
 *       </all>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ConverterOfficeWordType", propOrder = {

})
public class ConverterOfficeWordType {

    protected ConverterOfficeFormType form;

    /**
     * Gets the value of the form property.
     * 
     * @return
     *     possible object is
     *     {@link ConverterOfficeFormType }
     *     
     */
    public ConverterOfficeFormType getForm() {
        return form;
    }

    /**
     * Sets the value of the form property.
     * 
     * @param value
     *     allowed object is
     *     {@link ConverterOfficeFormType }
     *     
     */
    public void setForm(ConverterOfficeFormType value) {
        this.form = value;
    }

    public boolean isSetForm() {
        return (this.form!= null);
    }

}

==> webpdf-wsclient-10.0.2-sources.jar: net/webpdf/wsclient/schema/operation/ConverterOfficeWordType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p532746_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:p882137_="https://jakarta.ee/xml/ns/jaxb" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;&#13;
 *                     Defines the settings to be used when converting Word (docx) documents.&#13;
 *                 &lt;/p&gt;
 * </pre>
 * 
 * <p>Java class for ConverterOfficeWordType complex type</p>.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.</p>
 * 
 * <pre>{@code
 * <complexType name="ConverterOfficeWordType">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <all>
 *         <element name="form" type="{http://schema.webpdf.de/1.0/operation}ConverterOfficeFormType" minOccurs="0"/>
 *       </all>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ConverterOfficeWordType", propOrder = {

})
public class ConverterOfficeWordType {

    protected ConverterOfficeFormType form;

    /**
     * Gets the value of the form property.
     * 
     * @return
     *     possible object is
     *     {@link ConverterOfficeFormType }
     *     
     */
    public ConverterOfficeFormType getForm() {
        return form;
    }

    /**
     * Sets the value of the form property.
     * 
     * @param value
     *     allowed object is
     *     {@link ConverterOfficeFormType }
     *     
     */
    public void setForm(ConverterOfficeFormType value) {
        this.form = value;
    }

    public boolean isSetForm() {
        return (this.form!= null);
    }

}
